#
# spec file for package qore-yaml-module
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?_datarootdir: %global mydatarootdir %_datarootdir}
%{!?_datarootdir: %global mydatarootdir /usr/share}

%global module_api %(qore --latest-module-api 2>/dev/null)
%global module_dir %{_libdir}/qore-modules
%global user_module_dir %{mydatarootdir}/qore-modules/

%if 0%{?sles_version}

%global dist .sles%{?sles_version}

%else
%if 0%{?suse_version}

# get *suse release major version
%global os_maj %(echo %suse_version|rev|cut -b3-|rev)
# get *suse release minor version without trailing zeros
%global os_min %(echo %suse_version|rev|cut -b-2|rev|sed s/0*$//)

%if %suse_version
%global dist .opensuse%{os_maj}_%{os_min}
%endif

%endif
%endif

%define src_name qore-yaml-module-%{version}
Name:           qore-yaml-module
Version:        1.0.0
Release:        1.1
Summary:        YAML module for Qore
License:        GPL-2.0-or-later OR LGPL-2.1-or-later OR MIT
Group:          Development/Languages/Misc
URL:            https://www.qore.org/
Source:         https://github.com/qorelanguage/module-yaml/releases/download/v%{version}/%{name}-%{version}.tar.bz2#/%{name}-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       /usr/bin/env
Requires:       qore-module(abi)%{?_isa} = %{module_api}
BuildRequires:  cmake >= 3.5
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz
BuildRequires:  libyaml-devel
BuildRequires:  qore >= 2.0
BuildRequires:  qore-devel >= 2.0
BuildRequires:  timezone
BuildRequires:  (qore-stdlib if qore >= 2.0)
Suggests:       %{name}-doc = %{version}

%description
This package contains the yaml module for the Qore Programming Language.

YAML is a flexible and concise human-readable data serialization format.

%if 0%{?suse_version}
%endif

%package doc
Summary:        Documentation and examples for the Qore yaml module
Group:          Development/Languages/Misc
BuildArch:      noarch

%description doc
This package contains the HTML documentation and example programs for the Qore
yaml module.

%files doc
%defattr(-,root,root)
%doc docs/yaml docs/YamlRpcClient docs/YamlRpcHandler docs/DataStreamUtil docs/DataStreamClient docs/DataStreamRequestHandler test examples

%prep
%setup -q -n %{src_name}
find examples -type f|xargs chmod 644

%build
export CMAKE_POLICY_VERSION_MINIMUM=3.5
export CXXFLAGS="%{?optflags}"
cmake -DCMAKE_INSTALL_PREFIX=%{_prefix} -DCMAKE_BUILD_TYPE=RELWITHDEBINFO -DCMAKE_SKIP_RPATH=1 -DCMAKE_SKIP_INSTALL_RPATH=1 -DCMAKE_SKIP_BUILD_RPATH=1 -DCMAKE_PREFIX_PATH=${_prefix}/lib64/cmake/Qore .
make %{?_smp_mflags}
make %{?_smp_mflags} docs
sed -i 's/#!\/usr\/bin\/env qore/#!\/usr\/bin\/qore/' test/*.qtest examples/*

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
%fdupes -s %{__builddir}/html docs

%files
%defattr(-,root,root)
%license COPYING.LGPL COPYING.MIT
%doc README RELEASE-NOTES AUTHORS
%{module_dir}
%{user_module_dir}

%check
export QORE_MODULE_DIR=$QORE_MODULE_DIR:qlib
qore -l ./yaml-api-%{module_api}.qmod test/DataStreamClient.qtest -v
qore -l ./yaml-api-%{module_api}.qmod test/DataStreamHandler.qtest -v
qore -l ./yaml-api-%{module_api}.qmod test/DataStreamUtil.qtest -v
qore -l ./yaml-api-%{module_api}.qmod test/YamlRpcHandler.qtest -v
qore -l ./yaml-api-%{module_api}.qmod test/yaml.qtest -v

%changelog
* Tue May 13 2025 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to version 1.0.0 for qore 2.1.1
  * fixed a bug parsing single-quoted date-only strings (ex: 2022-02-22),
    previously parsed as date/time values, now parsed correctly as strings
  * fixed a bug parsing n; was parsed as 0n before, now parsed correctly
  * fixed a bug where aliases in YAML caused parsing to fail
- export CMAKE_POLICY_VERSION_MINIMUM="3.5" to ignore cmakes
  minimum version warnings (boo#1241902)
* Sun May 26 2024 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Remove BuildRequirement qore-stdlib after the move of qore-stdlib to qore
* Sat Jul 22 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update %%{module_api} for yaml api checks
- Fix build with new qore (1.16.1)
* Sun Jan  8 2023 Sarah Kriesch <sarah.kriesch@opensuse.org>
- Update to version 0.7.3 for qore 1.0.14
  * Updated to build with qpp from Qore 1.12.4+
  * improved deserialization of date/time values; fixed a bug where
    a random string could be deserialized as a duration
  * Bugfix where REST schema validation was not applied in the
    DataStreamClient module with non-DataStream messages
* Mon Jun  6 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Version schema changed now offically released 0.7
- Fix build with new qore (1.8.0)
* Thu Oct 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.7.0 for Qore 1.0.10
  * Fixed module namespace paths
  * Fixed deserializing string values
  * Fixed handling serialization errors in YAML-RPC responses
* Tue Jun  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Revert last changes, version is not the git tag!
  Tag describes the qore version this module supports, base version
  is set inside the CMakeLists.txt
- Update to version 0.7.0 with qore release 0.9.15
  * Fix: single quoted string
  * allow connections to be created dynamically over the network
  * Support QoreValue API
  * Bug fixes
  * https://github.com/qorelanguage/module-yaml/compare/v0.6...release-0.9.15
* Tue May 18 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.0.0
  * https://github.com/qorelanguage/module-yaml/compare/v0.6...release-1.0.0
* Sat Dec 19 2020 sarah.kriesch@opensuse.org
- enable s390x as an architecture in spec file
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6:
  * improved the description for the DESERIALIZATION-ERROR exception for
  non-deserializable message bodies from HTTP servers with error responses (issue
  1033) added the YamlRpcConnection class to the YamlRpcClient module updated the
  DataStreamClient module for complex types and new internal RestClient API
  changes (issue 2073) updated the DataStreamUtil module for complex types
  fixed a bug deserializing single-quoted strings; also serialized "!number"
  values will always include the tag to avoid potential future ambiguity (issue
  2343) improved argument error messages with RPC calls in the YamlRpcHandler
  module (issue 2573)
  * new user modules for DataStream protocol support: YAML-encoded HTTP chunked
  transfers where each chunk is a unique data entity DataStreamClient user module
  DataStreamRequestHandler user module
  DataStreamUtil user module
  * user modules moved to top-level qore module directory from version-specific
  module directory since they are valid for multiple versions of qore date/time
  values (yaml !!timestamp type) are now always returned in the current time zone
  locale so that time zone rules can be applied to deserialized dates; previously
  time zone information was always lost which could cause errors when performing
  date arithmetic on deserialized yaml dates
  * fixed bugs deserializing canonically-encoded YAML strings; arbitrary-precision
  numeric values were deserialized with their precision values ignored and
  floating point +/-inf were deserialized as zero deprecated old camel-case names
  and implemented new function names confirming to the standard naming convention
  for functions
* Mon Aug 31 2015 normand@linux.vnet.ibm.com
- add --enable-64bit as already done for other qore-*-module
* Wed Jul 30 2014 petr@yarpen.cz
- migrated to OBS file layout
